"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const plugin_1 = require("@stryker-mutator/api/plugin");
const fs = require("fs");
const path = require("path");
exports.CONFIG_KEY = 'babel';
exports.FILE_KEY = 'optionsFile';
exports.OPTIONS_KEY = 'options';
exports.EXTENSIONS_KEY = 'extensions';
const DEFAULT_BABEL_CONFIG = Object.freeze({
    extensions: Object.freeze([]),
    options: Object.freeze({}),
    optionsFile: '.babelrc'
});
class BabelConfigReader {
    constructor(log) {
        this.log = log;
    }
    readConfig(strykerOptions) {
        const babelConfig = Object.assign({}, DEFAULT_BABEL_CONFIG, strykerOptions[exports.CONFIG_KEY]);
        babelConfig.options = Object.assign({}, this.readBabelOptionsFromFile(babelConfig.optionsFile, babelConfig.optionsApi), babelConfig.options);
        this.log.debug(`Babel config is: ${JSON.stringify(babelConfig, null, 2)}`);
        return babelConfig;
    }
    readBabelOptionsFromFile(relativeFileName, optionsApi) {
        if (relativeFileName) {
            const babelrcPath = path.resolve(relativeFileName);
            this.log.debug(`Reading .babelrc file from path "${babelrcPath}"`);
            if (fs.existsSync(babelrcPath)) {
                try {
                    if (path.basename(babelrcPath) === '.babelrc.js') {
                        return require(babelrcPath);
                    }
                    if (path.basename(babelrcPath) === 'babel.config.js') {
                        const config = require(babelrcPath);
                        return config(optionsApi);
                    }
                    return JSON.parse(fs.readFileSync(babelrcPath, 'utf8'));
                }
                catch (error) {
                    this.log.error(`Error while reading "${babelrcPath}" file: ${error}`);
                }
            }
            else {
                this.log.error(`babelrc file does not exist at: ${babelrcPath}`);
            }
        }
        return {};
    }
}
BabelConfigReader.inject = plugin_1.tokens(plugin_1.commonTokens.logger);
exports.BabelConfigReader = BabelConfigReader;
//# sourceMappingURL=BabelConfigReader.js.map